@@ -1115,15 +1115,19 @@ int
 main (int argc,
       char **argv)
 {
+	GnomeProgram *program;
+
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv, GNOME_PARAM_APP_DATADIR, DATADIR,NULL);
+	program = gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE,
+				      argc, argv, GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
 	g_idle_add (track_editor_init, NULL);
 	bonobo_main ();
 
+	g_object_unref (program);
+
 	exit (0);
 }
