@@ -38,20 +38,15 @@
 #include <math.h>
 
 #include <glib/gi18n.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <libgnome/gnome-help.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <gconf/gconf-client.h>
 #include <gst/gst.h>
 #include <gst/interfaces/mixer.h>
 
 #include <profiles/gnome-media-profiles.h>
 
-#include "egg-recent-view.h"
-#include "egg-recent-view-gtk.h"
-#include "egg-recent-model.h"
-#include "egg-recent-util.h"
-
 #include "gsr-window.h"
 
 GST_DEBUG_CATEGORY_STATIC (gsr_debug);
@@ -62,7 +57,6 @@ extern void gsr_quit (void);
 
 extern GConfClient *gconf_client;
 
-extern EggRecentModel *recent_model;
 extern void gsr_add_recent (gchar *filename);
 
 #define GCONF_DIR           "/apps/gnome-sound-recorder/"
@@ -96,6 +90,7 @@ struct _GSRWindowPrivate {
 	GtkWidget *scale;
 	GtkWidget *profile, *input;
 	GtkWidget *rate, *time_sec, *format, *channels;
+	GtkWidget *input_label;
 	GtkWidget *name_label;
 	GtkWidget *length_label;
 	GtkWidget *align;
@@ -106,7 +101,8 @@ struct _GSRWindowPrivate {
 
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
-	EggRecentViewGtk *recent_view;
+	GtkWidget *recent_view;
+	GtkRecentFilter *recent_filter;
 
 	/* statusbar */
 	GtkWidget *statusbar;
@@ -424,14 +420,13 @@ file_open_cb (GtkAction *action,
 }
 
 static void
-file_open_recent_cb (EggRecentViewGtk *view,
-		     EggRecentItem *item,
+file_open_recent_cb (GtkRecentChooser *chooser,
 		     GSRWindow *window)
 {
 	gchar *uri;
 	gchar *filename;
 
-	uri = egg_recent_item_get_uri (item);
+	uri = gtk_recent_chooser_get_current_uri (chooser);
 	g_return_if_fail (uri != NULL);
 
 	if (!g_str_has_prefix (uri, "file://"))
@@ -456,7 +451,7 @@ file_open_recent_cb (EggRecentViewGtk *view,
 		gtk_dialog_run (GTK_DIALOG (dlg));
 		gtk_widget_destroy (dlg);
 
-		egg_recent_model_delete (recent_model, uri);
+		gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uri, NULL);
 
 		g_free (filename_utf8);
 		goto out;
@@ -677,9 +672,9 @@ do_save_file (GSRWindow *window,
 	      const char *_name)
 {
 	GSRWindowPrivate *priv;
-	char *tmp, *src, *name;
-	gchar *utf8_name = NULL;
-	GnomeVFSURI *src_uri, *dst_uri;
+	char *name;
+	GFile *src, *dst;
+	GError *error = NULL;
 
 	priv = window->priv;
 
@@ -690,6 +685,7 @@ do_save_file (GSRWindow *window,
 		name = g_strdup_printf ("%s.%s", _name,
 				window->priv->extension);
 	if (g_file_test (name, G_FILE_TEST_EXISTS)) {
+		char *utf8_name;
 		utf8_name = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
 		if (!replace_existing_file (GTK_WINDOW (window), utf8_name)) {
 			g_free (utf8_name);
@@ -697,42 +693,29 @@ do_save_file (GSRWindow *window,
 		}
 		g_free (utf8_name);
 	}
+	src = g_file_new_for_path(priv->record_filename);
+	dst = g_file_new_for_path(name);
 
-	tmp = gnome_vfs_make_uri_from_shell_arg (name);
-	src = gnome_vfs_make_uri_from_shell_arg (priv->record_filename);
-	src_uri = gnome_vfs_uri_new (src);
-	dst_uri = gnome_vfs_uri_new (tmp);
-	g_free (src);
-	if (src_uri && dst_uri) {
-		GnomeVFSResult result;
-		result = gnome_vfs_xfer_uri (src_uri, dst_uri,
-			GNOME_VFS_XFER_DEFAULT,
-			GNOME_VFS_XFER_ERROR_MODE_ABORT,
-			GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-			NULL, NULL);
-		if (result == GNOME_VFS_OK) {
-			g_object_set (G_OBJECT (window), "location", name, NULL);
-			priv->dirty = FALSE;
-			window->priv->saved = TRUE;
-			if (window->priv->quit_after_save == TRUE) {
-				gsr_window_close (window);
-			}
-		} else {
-			show_error_dialog (GTK_WINDOW (window), NULL,
-			                   _("Could not save the file \"%s\""),
-			                   gnome_vfs_result_to_string (result));
+	/* TODO: Show progress? Where? */
+	if (g_file_copy(src, dst, G_FILE_COPY_OVERWRITE,
+	                NULL, NULL, NULL, &error)) {
+		g_object_set (G_OBJECT (window), "location", name, NULL);
+		priv->dirty = FALSE;
+		window->priv->saved = TRUE;
+		if (window->priv->quit_after_save == TRUE) {
+			gsr_window_close (window);
 		}
-		gnome_vfs_uri_unref (src_uri);
-		gnome_vfs_uri_unref (dst_uri);
 	} else {
+		char *utf8_name;
 		utf8_name = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
 		show_error_dialog (GTK_WINDOW (window), NULL,
 			           _("Could not save the file \"%s\""), utf8_name);
 		g_free (utf8_name);
 	}
 
+	g_object_unref(src);
+	g_object_unref(dst);
 	g_free (name);
-	g_free (tmp);
 }
 
 static void
@@ -1011,7 +994,7 @@ fill_in_information (GSRWindow *window,
 		gchar *human;
 
 		file_size = (guint64) buf.st_size;
-		human = gnome_vfs_format_file_size_for_display (file_size);
+		human = g_format_size_for_display (file_size);
 
 		text = g_strdup_printf (ngettext ("%s (%llu byte)", "%s (%llu bytes)", 
 		                        file_size), human, file_size);
@@ -1252,7 +1235,7 @@ about_cb (GtkAction *action,
 			       "name", _("Sound Recorder"),
 			       "version", VERSION,
 			       "copyright", "Copyright \xc2\xa9 2002 Iain Holmes",
-			       "comments", _("A sound recorder for GNOME\n gnome-media@gnome.org"),
+			       "comments", _("A sound recorder for GNOME\n gnome-multimedia@gnome.org"),
 			       "authors", authors,
 			       "documenters", documenters,
 			       "logo-icon-name", "gnome-sound-recorder",
@@ -1275,11 +1258,14 @@ play_cb (GtkAction *action,
 	if ((priv->play = make_play_pipeline (window))) {
 		gchar *uri;
 		gchar *usefile;
+		GFile *file;
 
 		if(priv->has_file == FALSE && priv->working_file) usefile = priv->working_file;
 		else usefile = priv->filename;
 
-		uri = gnome_vfs_make_uri_from_shell_arg (usefile);
+		file = g_file_new_for_commandline_arg (usefile);
+		uri = g_file_get_uri (file);
+		g_object_unref (file);
 		g_object_set (window->priv->play->pipeline, "uri", uri, NULL);
 		g_free (uri);
 
@@ -1326,7 +1312,7 @@ record_cb (GtkAction *action,
 		char *current_source;
 		shutdown_pipeline (priv->record);
 		if (!make_record_source (window))
-			g_assert_not_reached ();
+			return;
 		current_source = gtk_combo_box_get_active_text (GTK_COMBO_BOX (window->priv->input));
 		fill_record_input (window, current_source);
 	}
@@ -1794,6 +1780,8 @@ record_state_changed_cb (GstBus *bus, GstMessage *msg, GSRWindow *window)
 		set_action_sensitive (window, "FileSave", TRUE);
 		set_action_sensitive (window, "FileSaveAs", TRUE);
 		gtk_widget_set_sensitive (window->priv->scale, FALSE);
+		gtk_widget_set_sensitive (window->priv->profile, TRUE);
+		gtk_widget_set_sensitive (window->priv->input, TRUE);
 
 		gtk_statusbar_pop (GTK_STATUSBAR (window->priv->statusbar),
 				   window->priv->status_message_cid);
@@ -1904,7 +1892,14 @@ fill_record_input (GSRWindow *window, gchar *selected)
 
 	if (model) 
 		gtk_list_store_clear (GTK_LIST_STORE (model));
-	
+
+	if (GST_IS_MIXER (window->priv->mixer) == FALSE
+	    || gst_mixer_list_tracks (window->priv->mixer) == NULL) {
+		gtk_widget_hide (window->priv->input);
+		gtk_widget_hide (window->priv->input_label);
+		return;
+	}
+
 	gtk_widget_set_sensitive (window->priv->input, GST_IS_MIXER (window->priv->mixer));
 	if (!GST_IS_MIXER (window->priv->mixer))
 		return;
@@ -1924,6 +1919,9 @@ fill_record_input (GSRWindow *window, gchar *selected)
 			gtk_combo_box_set_active (GTK_COMBO_BOX (window->priv->input), i - 1);
 		}
 	}
+
+	gtk_widget_show (window->priv->input);
+	gtk_widget_show (window->priv->input_label);
 }
 
 gboolean
@@ -2044,20 +2042,18 @@ make_record_pipeline (GSRWindow *window)
 
 	/* now link it all together */
 	if (!(gst_element_link_many (source, level, encoder, NULL))) {
-		show_profile_error (NULL, err->message,
+		show_profile_error (NULL, NULL,
 			_("Could not capture using the '%s' audio profile. "),
 			name);
-		g_error_free (err);
 		gst_object_unref (pipeline->pipeline);
 		g_free (pipeline);
 		return NULL;
 	}
 
 	if (!gst_element_link (encoder, filesink)) {
-		show_profile_error (NULL, err->message,
+		show_profile_error (NULL, NULL,
 			_("Could not write to a file using the '%s' audio profile. "),
 			name);
-		g_error_free (err);
 		gst_object_unref (pipeline->pipeline);
 		g_free (pipeline);
 		return NULL;
@@ -2314,12 +2310,13 @@ gsr_window_init (GSRWindow *window)
 	submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (file_menu));
 	rec_menu = gtk_ui_manager_get_widget (priv->ui_manager,
 					      "/MenuBar/FileMenu/FileRecentMenu");
-	priv->recent_view = egg_recent_view_gtk_new (submenu, rec_menu);
-	egg_recent_view_gtk_show_icons (EGG_RECENT_VIEW_GTK (priv->recent_view),
-					FALSE);
-	egg_recent_view_gtk_set_trailing_sep (priv->recent_view, TRUE);
-	egg_recent_view_set_model (EGG_RECENT_VIEW (priv->recent_view), recent_model); 
-	g_signal_connect (priv->recent_view, "activate",
+	priv->recent_view = gtk_recent_chooser_menu_new ();
+	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (priv->recent_view), TRUE);
+	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (priv->recent_view), 5);
+	priv->recent_filter = gtk_recent_filter_new ();
+	gtk_recent_filter_add_application (priv->recent_filter, g_get_application_name ());
+	gtk_recent_chooser_set_filter (GTK_RECENT_CHOOSER (priv->recent_view), priv->recent_filter);
+	g_signal_connect (priv->recent_view, "item-activated",
 			  G_CALLBACK (file_open_recent_cb), window);
 
 	/* window content: hscale, labels, etc */
@@ -2347,19 +2344,17 @@ gsr_window_init (GSRWindow *window)
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (content_vbox), hbox, FALSE, FALSE, 0);
 
-	label = gtk_label_new_with_mnemonic (_("Record from _input:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	priv->input_label = gtk_label_new_with_mnemonic (_("Record from _input:"));
+	gtk_misc_set_alignment (GTK_MISC (priv->input_label), 0, 0.5);
+	gtk_box_pack_start (GTK_BOX (hbox), priv->input_label, FALSE, FALSE, 0);
 
 	priv->input = gtk_combo_box_new_text ();
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), priv->input);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->input_label), priv->input);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->input, TRUE, TRUE, 0);
-	gtk_widget_show (priv->input);
 
 	if (!make_record_source (window))
-		g_assert_not_reached ();
+		exit (1);
 
-	fill_record_input (window, NULL);
 	g_signal_connect (priv->input, "changed",
 			  G_CALLBACK (record_input_changed_cb), window);
 
@@ -2495,6 +2490,7 @@ gsr_window_init (GSRWindow *window)
 			    _("Ready"));
 
 	gtk_widget_show_all (main_vbox);
+	fill_record_input (window, NULL);
 
 	/* Make the pipelines */
 	priv->play = NULL;
@@ -2556,9 +2552,7 @@ gsr_window_set_property (GObject      *object,
 			gtk_label_set (GTK_LABEL (priv->name_label), utf8_name);
 		}
 
-		if (recent_model) {
-			gsr_add_recent (priv->filename);
-		}
+		gsr_add_recent (priv->filename);
 
 		/*Translators: this is the window title, %s is the currently open file's name or Untitled*/
 		title = g_strdup_printf (_("%s - Sound Recorder"), utf8_name);
@@ -2571,7 +2565,7 @@ gsr_window_set_property (GObject      *object,
 		set_action_sensitive (window, "Stop", FALSE);
 		set_action_sensitive (window, "Record", TRUE);
 		set_action_sensitive (window, "FileSave", window->priv->has_file ? TRUE : FALSE);
-		set_action_sensitive (window, "FileSaveAs", window->priv->has_file ? TRUE : FALSE);
+		set_action_sensitive (window, "FileSaveAs", TRUE);
 		break;
 	default:
 		break;
