@@ -58,30 +58,22 @@ gnome_volume_control_element_init (GnomeVolumeControlElement *el)
 {
   el->client = NULL;
   el->mixer = NULL;
-  el->statusbar = NULL;
 }
 
 GtkWidget *
-gnome_volume_control_element_new (GstElement   *element,
-				  GConfClient  *client,
-				  GtkStatusbar *statusbar)
+gnome_volume_control_element_new (GConfClient  *client)
 {
   GnomeVolumeControlElement *el;
 
-  g_return_val_if_fail (GST_IS_MIXER (element), NULL);
-
   /* element */
   el = g_object_new (GNOME_VOLUME_CONTROL_TYPE_ELEMENT, NULL);
   el->client = g_object_ref (G_OBJECT (client));
-  el->statusbar = statusbar;
 
   gconf_client_add_dir (el->client, GNOME_VOLUME_CONTROL_KEY_DIR,
 			GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
   gconf_client_notify_add (el->client, GNOME_VOLUME_CONTROL_KEY_DIR,
 			   cb_gconf, el, NULL, NULL);
 
-  gnome_volume_control_element_change (el, element);
-
   return GTK_WIDGET (el);
 }
 
@@ -156,7 +148,7 @@ update_tab_visibility (GnomeVolumeControlElement *el, gint page)
        item != NULL; item = item->next) {
     GstMixerTrack *track = item->data;
     GnomeVolumeControlTrack *trkw =
-        g_object_get_data (G_OBJECT (track), "gnome-volume-control-trkw"); 
+        g_object_get_data (G_OBJECT (track), "gnome-volume-control-trkw");
 
     if (get_page_num (track) == page && trkw->visible) {
       visible = TRUE;
@@ -171,6 +163,36 @@ update_tab_visibility (GnomeVolumeControlElement *el, gint page)
     gtk_widget_hide (t);
 }
 
+static void
+cb_notify_message (GstBus *bus, GstMessage *message, gpointer data)
+{
+  GnomeVolumeControlElement *el = data;
+  GstMixerMessageType type;
+  GnomeVolumeControlTrack *trkw;
+  GstMixerTrack *track = NULL;
+
+  if (GST_MESSAGE_SRC (message) != GST_OBJECT (el->mixer)) {
+    /* not from our mixer - can't update anything anyway */
+    return;
+  }
+
+  /* This code only calls refresh if the first_track changes, because the
+   * refresh code only retrieves the current value from that track anyway */
+  type = gst_mixer_message_get_type (message);
+  if (type == GST_MIXER_MESSAGE_MUTE_TOGGLED) {
+    gst_mixer_message_parse_mute_toggled (message, &track, NULL);
+  } else if (type == GST_MIXER_MESSAGE_VOLUME_CHANGED) {
+    gst_mixer_message_parse_volume_changed (message, &track, NULL, NULL);
+  } else {
+    return;
+  }
+
+  trkw = g_object_get_data (G_OBJECT (track),
+			    "gnome-volume-control-trkw");
+
+  gnome_volume_control_track_update (trkw);
+}
+
 /*
  * Change the element. Basically recreates this object internally.
  */
@@ -189,8 +211,7 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
 						    GstMixer      *mixer,
 						    GstMixerTrack *track,
 						    GtkWidget     *left_sep,
-						    GtkWidget     *right_sep,
-						    GtkStatusbar  *statusbar);
+						    GtkWidget     *right_sep);
   } content[4] = {
     { _("Playback"), NULL, NULL, NULL, FALSE, 0, 5, 1,
       gnome_volume_control_track_add_playback },
@@ -205,6 +226,7 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
   gint i;
   const GList *item;
   GstMixer *mixer;
+  GstBus *bus;
 
   /* remove old pages */
   while (gtk_notebook_get_n_pages (GTK_NOTEBOOK (el)) > 0) {
@@ -220,6 +242,7 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
 
       trkw = g_object_get_data (G_OBJECT (track),
 				"gnome-volume-control-trkw");
+      g_object_set_data (G_OBJECT (track), "gnome-volume-control-trkw", NULL);
       gnome_volume_control_track_free (trkw);
     }
   }
@@ -230,6 +253,15 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
   mixer = GST_MIXER (element);
   gst_object_replace ((GstObject **) &el->mixer, GST_OBJECT (element));
 
+  /* Bus for notifications */
+  if (GST_ELEMENT_BUS (mixer) == NULL) {
+    bus = gst_bus_new ();
+    gst_bus_add_signal_watch (bus);
+    g_signal_connect (G_OBJECT (bus), "message::element",
+		      (GCallback) cb_notify_message, el);
+    gst_element_set_bus (GST_ELEMENT (mixer), bus);
+  }
+
   /* content pages */
   for (i = 0; i < 4; i++) {
     content[i].page = gtk_table_new (content[i].width, content[i].height, FALSE);
@@ -280,8 +312,7 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
     /* widget */
     trkw = content[i].get_track_widget (GTK_TABLE (content[i].page),
 					content[i].pos++, el->mixer, track,
-					content[i].old_sep, content[i].new_sep,
-					el->statusbar);
+					content[i].old_sep, content[i].new_sep);
     gnome_volume_control_track_show (trkw, active);
 
     g_object_set_data (G_OBJECT (track),
@@ -374,7 +405,10 @@ cb_gconf (GConfClient *client,
 	g_object_get_data (G_OBJECT (track), "gnome-volume-control-trkw");
       gchar *key = get_gconf_key (el->mixer, track);
 
-      if (!strcmp (gconf_entry_get_key (entry), key)) {
+      g_return_if_fail (gconf_entry_get_key (entry) != NULL);
+      g_return_if_fail (key != NULL);
+
+      if (g_str_equal (gconf_entry_get_key (entry), key)) {
         GConfValue *value = gconf_entry_get_value (entry);
 
         if (value->type == GCONF_VALUE_BOOL) {
