@@ -24,7 +24,6 @@
 
 #include <glib.h>
 #include <gtk/gtknotebook.h>
-#include <gtk/gtkstatusbar.h>
 #include <gconf/gconf-client.h>
 #include <gst/interfaces/mixer.h>
 
@@ -51,9 +50,6 @@ typedef struct _GnomeVolumeControlElement {
 
   /* gconf client inherited from our parent */
   GConfClient *client;
-
-  /* status bar */
-  GtkStatusbar *statusbar;
 } GnomeVolumeControlElement;
 
 typedef struct _GnomeVolumeControlElementClass {
@@ -61,9 +57,7 @@ typedef struct _GnomeVolumeControlElementClass {
 } GnomeVolumeControlElementClass;
 
 GType		gnome_volume_control_element_get_type	(void);
-GtkWidget *	gnome_volume_control_element_new	(GstElement   *element,
-							 GConfClient  *client,
-							 GtkStatusbar *statusbar);
+GtkWidget *	gnome_volume_control_element_new	(GConfClient  *client);
 void		gnome_volume_control_element_change	(GnomeVolumeControlElement *el,
 							 GstElement  *element);
 
