@@ -18,11 +18,15 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gtk/gtk.h>
-#include <gst/gst.h>
 #include <gconf/gconf-client.h>
 #include <libgnomeui/libgnomeui.h>
+#include <gst/gst.h>
+
 #include <profiles/gnome-media-profiles.h>
 
 static void
@@ -47,9 +51,11 @@ test_clicked_cb (GtkButton *button, GtkWidget *combo)
   GstMessage *msg = NULL;
   GstBus *bus = NULL;
 
+  profile = gm_audio_profile_choose_get_active (combo);
+  g_return_if_fail (profile != NULL);
+
   gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
 
-  profile = gm_audio_profile_choose_get_active (combo);
   extension = g_strdup (gm_audio_profile_get_extension (profile));
   partialpipe = g_strdup (gm_audio_profile_get_pipeline (profile));
 
